@@ -12,6 +12,10 @@ dp[]
 dp[] = 1:2
 dp[]
 
+dp[ c(1, 3) ]
+
+dp[ c(FALSE, FALSE, TRUE, TRUE) ]
+
 ###############
 
 i = 1:10
@@ -24,6 +28,10 @@ ip[]
 ip[] = c(2, 3)
 ip[]
 
+ip[1:3]
+ip[6:8]
+
+ip[ rep(c( TRUE, FALSE), 5) ]
 
 
 
