@@ -2,7 +2,8 @@ library(RCUDA)
 
 cuGetContext(TRUE)
 
-vals = profileCuda(
+
+vals = profileCUDA(
  {
    m = loadModule(system.file("sampleKernels", "dnorm.ptx", package = "RCUDA"))
    k = m$dnorm_kernel
@@ -15,8 +16,8 @@ vals = profileCuda(
    mu = 0.3
    sigma = 1.5
 
-   .cuda(k, mem, N, mu, sigma, inplace = TRUE, gridDim = c(32L, 2L, 1L), blockDim = c(32L, 1L, 1L))
- }, "prof.out", "prof.config")
+   .cuda(k, mem, N, mu, sigma, gridDim = c(64L, 64L, 1L), blockDim = c(512L, 1L, 1L))
+ }, "prof.out")
 
 
 
